summaryrefslogtreecommitdiffstats
path: root/kde.py
diff options
context:
space:
mode:
Diffstat (limited to 'kde.py')
-rw-r--r--kde.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/kde.py b/kde.py
index 83c660a..1022c1f 100644
--- a/kde.py
+++ b/kde.py
@@ -156,10 +156,10 @@ def detect_kde(env):
if os.path.isfile(kdeincludes + "/klineedit.h"):
print GREEN + "ok " + kdeincludes + NORMAL
else:
- if os.path.isfile(kdeprefix+"/include/kde/klineedit.h"):
+ if os.path.isfile(kdeprefix+"/include/tde/klineedit.h"):
# Debian, Fedora probably
- print YELLOW + "the kde headers were found in " + kdeprefix + "/include/kde/" + NORMAL
- kdeincludes = kdeprefix + "/include/kde/"
+ print YELLOW + "the kde headers were found in " + kdeprefix + "/include/tde/" + NORMAL
+ kdeincludes = kdeprefix + "/include/tde/"
else:
print RED + "The kde includes were NOT found" + NORMAL
env.Exit(1)
@@ -231,7 +231,7 @@ def generate(env):
"""+BOLD+"""* datadir """+NORMAL+""": install path for the data, ie: /usr/local/share
"""+BOLD+"""* libdir """+NORMAL+""": install path for the libs, ie: /usr/lib
"""+BOLD+"""* libsuffix """+NORMAL+""": suffix of libraries on amd64, ie: 64, 32
"""+BOLD+"""* kdeincludes"""+NORMAL+""": path to the kde includes (/usr/include/kde on debian, ...)
"""+BOLD+"""* qtincludes """+NORMAL+""": same punishment, for qt includes (/usr/include/qt on debian, ...)
"""+BOLD+"""* tdelibs """+NORMAL+""": path to the kde libs, for linking the programs
"""+BOLD+"""* qtlibs """+NORMAL+""": same punishment, for qt libraries
@@ -231,7 +231,7 @@ def generate(env):
"""+BOLD+"""* libdir """+NORMAL+""": install path for the libs, ie: /usr/lib
"""+BOLD+"""* libsuffix """+NORMAL+""": suffix of libraries on amd64, ie: 64, 32
-"""+BOLD+"""* kdeincludes"""+NORMAL+""": path to the kde includes (/usr/include/kde on debian, ...)
+"""+BOLD+"""* kdeincludes"""+NORMAL+""": path to the kde includes (/usr/include/tde on debian, ...)
"""+BOLD+"""* qtincludes """+NORMAL+""": same punishment, for qt includes (/usr/include/qt on debian, ...)
"""+BOLD+"""* tdelibs """+NORMAL+""": path to the kde libs, for linking the programs